@@ -10,8 +10,10 @@ from inelsmqtt.util import DeviceValue
 from inelsmqtt.devices import Device, DeviceInfo
 from inelsmqtt.const import (
     BATTERY,
+    CLIMATE,
     COVER,
     MANUFACTURER,
+    RFATV_1,
     RFJA_12,
     STATE_CLOSED,
     STATE_OPEN,
@@ -50,6 +52,9 @@ from tests.const import (
     TEST_LIGH_STATE_INELS_VALUE,
     TEST_LIGHT_DIMMABLE_TOPIC_STATE,
     TEST_LIGHT_SET_INELS_VALUE,
+    TEST_CLIMATE_RFATV_1_STATE_VALUE,
+    TEST_CLIMATE_RFATV_1_TOPIC_CONNECTED,
+    TEST_CLIMATE_RFATV_1_TOPIC_STATE,
     TEST_SENSOR_TOPIC_STATE,
     TEST_AVAILABILITY_OFF,
     TEST_AVAILABILITY_ON,
@@ -101,6 +106,9 @@ class DeviceTest(TestCase):
         self.shutter = Device(
             InelsMqtt(config), TEST_COVER_RFJA_12_TOPIC_STATE, "Shutter"
         )
+        self.valve = Device(
+            InelsMqtt(config), TEST_CLIMATE_RFATV_1_TOPIC_STATE, "Climate"
+        )
 
     def tearDown(self) -> None:
         """Destroy all instances and stop patches"""
@@ -108,6 +116,7 @@ class DeviceTest(TestCase):
         self.sensor = None
         self.light = None
         self.shutter = None
+        self.valve = None
 
     def test_initialize_device(self) -> None:
         """Test initialization of device object"""
@@ -335,3 +344,31 @@ class DeviceTest(TestCase):
             TEST_COVER_RFJA_12_INELS_STATE_OPEN.decode(),
         )
         self.assertEqual(self.shutter.state, STATE_OPEN)
+
+    @patch(f"{TEST_INELS_MQTT_CLASS_NAMESPACE}.messages")
+    def test_device_support_climate_initialized(self, mock_message) -> None:
+        """Test climate all props. initialization."""
+        mock_message.return_value = {
+            TEST_CLIMATE_RFATV_1_TOPIC_STATE: TEST_CLIMATE_RFATV_1_STATE_VALUE,
+            TEST_CLIMATE_RFATV_1_TOPIC_CONNECTED: TEST_AVAILABILITY_ON,
+        }
+
+        self.valve.get_value()
+
+        self.assertTrue(self.valve.is_available)
+        self.assertEqual(self.valve.device_type, CLIMATE)
+        self.assertEqual(self.valve.inels_type, RFATV_1)
+        self.assertEqual(self.valve.state, 26.0)
+
+    @patch(f"{TEST_INELS_MQTT_CLASS_NAMESPACE}.publish")
+    @patch(f"{TEST_INELS_MQTT_CLASS_NAMESPACE}.messages")
+    def test_device_set_climate_valve_value(self, mock_message, mock_publish) -> None:
+        """Test valve value."""
+        mock_message.return_value = {
+            TEST_CLIMATE_RFATV_1_TOPIC_STATE: TEST_CLIMATE_RFATV_1_STATE_VALUE
+        }
+        mock_publish.return_value = True
+
+        self.valve.set_ha_value(30)
+
+        self.assertEqual(self.valve.values.inels_set_value, "00 3C 00")
